@@ -205,11 +205,11 @@ def get_inbox_messages(pk_staff=None, pk_patient=None, include_without_provider=
 
 	return [ cInboxMessage(row = {'data': r, 'idx': idx, 'pk_field': 'pk_inbox_message'}) for r in rows ]
 #------------------------------------------------------------
-def create_inbox_message(message_type=None, subject=None, patient=None, staff=None):
+def create_inbox_message(message_type=None, subject=None, patient=None, staff=None, message_category=u'clinical'):
 
 	success, pk_type = gmTools.input2int(initial = message_type)
 	if not success:
-		pk_type = create_inbox_item_type(message_type = message_type)
+		pk_type = create_inbox_item_type(message_type = message_type, category = message_category)
 
 	cmd = u"""
 		INSERT INTO dem.message_inbox (
@@ -260,10 +260,10 @@ def create_inbox_item_type(message_type=None, category=u'clinical'):
 			pk_cat = rows[0]['pk']
 
 	# find type PK or create type
-	args = {u'cat': pk_cat, u'type': message_type}
+	args = {u'pk_cat': pk_cat, u'type': message_type}
 	cmd = u"""SELECT COALESCE (
-		(SELECT pk FROM dem.inbox_item_type where fk_inbox_item_category = %(cat)s and _(description) = %(type)s),
-		(SELECT pk FROM dem.inbox_item_type where fk_inbox_item_category = %(cat)s and description = %(type)s)
+		(SELECT pk FROM dem.inbox_item_type where fk_inbox_item_category = %(pk_cat)s AND _(description) = %(type)s),
+		(SELECT pk FROM dem.inbox_item_type where fk_inbox_item_category = %(pk_cat)s AND description = %(type)s)
 	) AS pk"""
 	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}])
 	if rows[0]['pk'] is None:
@@ -273,7 +273,7 @@ def create_inbox_item_type(message_type=None, category=u'clinical'):
 				description,
 				is_user
 			) VALUES (
-				%(cat)s,
+				%(pk_cat)s,
 				%(type)s,
 				TRUE
 			) RETURNING pk"""
@@ -414,6 +414,8 @@ def get_hints_for_patient(pk_identity=None):
 	curs.callproc('clin.get_hints_for_patient', [pk_identity])
 	rows = curs.fetchall()
 	idx = gmPG2.get_col_indices(curs)
+	curs.close()
+	conn.rollback()
 	return [ cDynamicHint(row = {'data': r, 'idx': idx, 'pk_field': 'pk'}) for r in rows ]
 
 #============================================================
