@@ -719,14 +719,14 @@ class cEmrExport:
                 txt += gmTools.wrap (
                     '%s %.8s: %s\n' % (
                         soap_entry['date'].strftime('%d.%m. %H:%M'),
-                        soap_entry['provider'],
+                        soap_entry['modified_by'],
                         soap_entry['narrative']
                     ), 75
                 )
 
 #                txt += (
  #                   (' ' * (left_margin+3)) +
-  #                  soap_entry['date'].strftime('%H:%M %.8s: ') % soap_entry['provider'] +
+  #                  soap_entry['date'].strftime('%H:%M %.8s: ') % soap_entry['modified_by'] +
    #                 soap_entry['narrative'].replace('\n', eol_w_margin) +
     #                '\n'
      #           )
@@ -996,7 +996,7 @@ class cEMRJournalExporter:
 				patient['firstnames'].replace(u' ', u'_'),
 				patient.get_formatted_dob(format = '%Y-%m-%d')
 			)
-			path = os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'EMR', patient['dirname'], filename))
+			path = os.path.expanduser(os.path.join('~', 'gnumed', patient['dirname'], filename))
 
 		f = codecs.open(filename = filename, mode = 'w+b', encoding = 'utf8', errors = 'replace')
 		self.export(target = f, patient = patient)
