@@ -1,8 +1,7 @@
-# -*- coding: utf8 -*-
+# -*- coding: utf-8 -*-
 __doc__ = """GNUmed internetworking tools."""
 
 #===========================================================================
-__version__ = "$Revision: 1.98 $"
 __author__ = "K. Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL v2 or later (details at http://www.gnu.org)"
 
@@ -38,8 +37,8 @@ def open_url_in_browser(url, new=2, autoraise=True, *args, **kwargs):
 	# url, new=0, autoraise=True
 	try:
 		webbrowser.open(url, new = new, autoraise = autoraise, **kwargs)
-	except (webbrowser.Error, OSError):
-		_log.exception('error calling browser')
+	except (webbrowser.Error, OSError, UnicodeEncodeError):
+		_log.exception('error calling browser with url=%s', url)
 		return False
 	return True
 #===========================================================================
