@@ -1107,13 +1107,15 @@ class cPersonNameEAPnl(wxgPersonNameEAPnl.wxgPersonNameEAPnl, gmEditArea.cGeneri
 			data = self.__identity.add_name(first, last, active)
 		except gmPG2.dbapi.IntegrityError as exc:
 			_log.exception('cannot save new name')
+			exc = make_pg_exception_fields_unicode(exc)
 			gmGuiHelpers.gm_show_error (
 				aTitle = _('Adding name'),
 				aMessage = _(
 					'Cannot add this name to the patient !\n'
 					'\n'
 					' %s'
-				) % str(exc)
+				) % exc.u_pgerror
+#				) % str(exc)
 			)
 			return False
 
@@ -1153,13 +1155,15 @@ class cPersonNameEAPnl(wxgPersonNameEAPnl.wxgPersonNameEAPnl, gmEditArea.cGeneri
 				name = self.__identity.add_name(first, last, active)
 			except gmPG2.dbapi.IntegrityError as exc:
 				_log.exception('cannot clone name when editing existing name')
+				exc = make_pg_exception_fields_unicode(exc)
 				gmGuiHelpers.gm_show_error (
 					aTitle = _('Editing name'),
 					aMessage = _(
 						'Cannot clone a copy of this name !\n'
 						'\n'
 						' %s'
-					) % str(exc)
+					) % exc.u_pgerror
+#					) % str(exc)
 				)
 				return False
 			name['preferred'] = gmTools.none_if(self._PRW_nick.GetValue().strip(), u'')
