@@ -2,7 +2,6 @@
 # GNUmed Richard style Edit Area
 #====================================================================
 __license__ = 'GPL'
-__version__ = "$Revision: 1.135 $"
 __author__ = "R.Terry, K.Hilbert"
 
 #======================================================================
@@ -20,7 +19,6 @@ from Gnumed.pycommon import gmDispatcher
 
 
 _log = logging.getLogger('gm.ui')
-_log.info(__version__)
 #====================================================================
 edit_area_modes = ['new', 'edit', 'new_from_existing']
 
@@ -74,7 +72,7 @@ class cXxxEAPnl(wxgXxxEAPnl.wxgXxxEAPnl, gmEditArea.cGenericEditAreaMixin):
 		if self._TCTRL_xxx.GetValue().strip() == u'':
 			validity = False
 			self.display_tctrl_as_valid(tctrl = self._TCTRL_xxx, valid = False)
-			gmDispatcher.send(signal = 'statustext', msg = _('No entry in field xxx.'))
+			self.status_message = _('No entry in field xxx.')
 			self._TCTRL_xxx.SetFocus()
 		else:
 			self.display_tctrl_as_valid(tctrl = self._TCTRL_xxx, valid = True)
@@ -82,7 +80,7 @@ class cXxxEAPnl(wxgXxxEAPnl.wxgXxxEAPnl, gmEditArea.cGenericEditAreaMixin):
 		if self._PRW_xxx.GetData() is None:
 			validity = False
 			self._PRW_xxx.display_as_valid(False)
-			gmDispatcher.send(signal = 'statustext', msg = _('No entry in field xxx.'))
+			self.status_message = _('No entry in field xxx.')
 			self._PRW_xxx.SetFocus()
 		else:
 			self._PRW_xxx.display_as_valid(True)
@@ -143,6 +141,8 @@ class cXxxEAPnl(wxgXxxEAPnl.wxgXxxEAPnl, gmEditArea.cGenericEditAreaMixin):
 		}
 		self._refresh_as_new()
 	#----------------------------------------------------------------
+	# properties
+	#----------------------------------------------------------------
 	def _get_mode(self):
 		return self.__mode
 
@@ -172,6 +172,13 @@ class cXxxEAPnl(wxgXxxEAPnl.wxgXxxEAPnl, gmEditArea.cGenericEditAreaMixin):
 
 	data = property(_get_data, _set_data)
 	#----------------------------------------------------------------
+	def show_msg(self, msg):
+		gmDispatcher.send(signal = 'statustext', msg = msg)
+
+	status_message = property(lambda x:x, show_msg)
+	#----------------------------------------------------------------
+	# generic edit area dialog API
+	#----------------------------------------------------------------
 	def save(self):
 		"""Invoked from the generic edit area dialog.
 
@@ -232,6 +239,7 @@ class cXxxEAPnl(wxgXxxEAPnl.wxgXxxEAPnl, gmEditArea.cGenericEditAreaMixin):
 	def display_ctrl_as_valid(self, ctrl=None, valid=None):
 		ctrl.SetBackgroundColour(self.__tctrl_validity_colors[valid])
 		ctrl.Refresh()
+
 #====================================================================
 from Gnumed.wxGladeWidgets import wxgGenericEditAreaDlg2
 
@@ -393,42 +401,6 @@ class cGenericEditAreaDlg2(wxgGenericEditAreaDlg2.wxgGenericEditAreaDlg2):
 
 	left_extra_button = property(lambda x:x, _set_left_extra_button)
 #====================================================================
-# DEPRECATED:
-from Gnumed.wxGladeWidgets import wxgGenericEditAreaDlg
-
-class cGenericEditAreaDlg(wxgGenericEditAreaDlg.wxgGenericEditAreaDlg):
-	"""Dialog for parenting edit area with save/clear/cancel"""
-
-	def __init__(self, *args, **kwargs):
-
-		ea = kwargs['edit_area']
-		del kwargs['edit_area']
-
-		wxgGenericEditAreaDlg.wxgGenericEditAreaDlg.__init__(self, *args, **kwargs)
-
-		szr = self._PNL_ea.GetContainingSizer()
-		szr.Remove(self._PNL_ea)
-		ea.Reparent(self)
-		szr.Add(ea, 1, wx.ALL|wx.EXPAND, 4)
-		self._PNL_ea = ea
-
-		self.Layout()
-		szr = self.GetSizer()
-		szr.Fit(self)
-		self.Refresh()
-
-		self._PNL_ea.refresh()
-	#--------------------------------------------------------
-	def _on_save_button_pressed(self, evt):
-		"""The edit area save() method must return True/False."""
-		if self._PNL_ea.save():
-			if self.IsModal():
-				self.EndModal(wx.ID_OK)
-			else:
-				self.Close()
-	#--------------------------------------------------------
-	def _on_clear_button_pressed(self, evt):
-		self._PNL_ea.refresh()
 #====================================================================
 #====================================================================
 #====================================================================
