@@ -14,7 +14,7 @@ from Gnumed.pycommon import gmExceptions
 from Gnumed.pycommon import gmNetworkTools
 from Gnumed.pycommon.gmTools import u_box_horiz_single
 
-from Gnumed.business import gmSurgery
+from Gnumed.business import gmPraxis
 
 from Gnumed.wxpython import gmGuiHelpers
 
@@ -233,8 +233,8 @@ def handle_uncaught_exception_wx(t, v, tb):
 	name, ext = os.path.splitext(name)
 	new_name = os.path.expanduser(os.path.join (
 		'~',
-		'gnumed',
-		'logs',
+		'.gnumed',
+		'error_logs',
 		'%s_%s%s' % (name, pyDT.datetime.now().strftime('%Y-%m-%d_%H-%M-%S'), ext)
 	))
 
@@ -247,6 +247,7 @@ def handle_uncaught_exception_wx(t, v, tb):
 
 	_log2.warning('syncing log file for backup to [%s]', new_name)
 	gmLog2.flush()
+	# keep a copy around
 	shutil.copy2(_logfile_name, new_name)
 # ------------------------------------------------------------------------
 def install_wx_exception_handler():
@@ -257,7 +258,7 @@ def install_wx_exception_handler():
 	global _local_account
 	_local_account = os.path.basename(os.path.expanduser('~'))
 
-	set_helpdesk(gmSurgery.gmCurrentPractice().helpdesk)
+	set_helpdesk(gmPraxis.gmCurrentPraxisBranch().helpdesk)
 	set_staff_name(_local_account)
 	set_is_public_database(False)
 	set_sender_email(None)
