@@ -282,113 +282,7 @@ class cMultilineTextEntryDlg(wxgMultilineTextEntryDlg.wxgMultilineTextEntryDlg):
 	def _on_restore_button_pressed(self, evt):
 		if self.original_text is not None:
 			self._TCTRL_text.SetValue(self.original_text)
-# ========================================================================
-from Gnumed.business import gmSurgery
-from Gnumed.wxGladeWidgets import wxgGreetingEditorDlg
 
-class cGreetingEditorDlg(wxgGreetingEditorDlg.wxgGreetingEditorDlg):
-
-	def __init__(self, *args, **kwargs):
-		wxgGreetingEditorDlg.wxgGreetingEditorDlg.__init__(self, *args, **kwargs)
-
-		self.surgery = gmSurgery.gmCurrentPractice()
-		self._TCTRL_message.SetValue(self.surgery.db_logon_banner)
-	#--------------------------------------------------------
-	# event handlers
-	#--------------------------------------------------------
-	def _on_save_button_pressed(self, evt):
-		self.surgery.db_logon_banner = self._TCTRL_message.GetValue().strip()
-		if self.IsModal():
-			self.EndModal(wx.ID_SAVE)
-		else:
-			self.Close()
-# ========================================================================
-class cTreeExpansionHistoryMixin:
-	"""TreeCtrl mixin class to record expansion history."""
-	def __init__(self):
-		if not isinstance(self, wx.TreeCtrl):
-			raise TypeError('[%s]: mixin can only be applied to wx.TreeCtrl, not [%s]' % (cTreeExpansionHistoryMixin, self.__class__.__name__))
-		self.expansion_state = {}
-	#--------------------------------------------------------
-	# public API
-	#--------------------------------------------------------
-	def snapshot_expansion(self):
-		self.__record_subtree_expansion(start_node_id = self.GetRootItem())
-	#--------------------------------------------------------
-	def restore_expansion(self):
-		if len(self.expansion_state) == 0:
-			return True
-		self.__restore_subtree_expansion(start_node_id = self.GetRootItem())
-	#--------------------------------------------------------
-	def print_expansion(self):
-		if len(self.expansion_state) == 0:
-			print "currently no expansion snapshot available"
-			return True
-		print "last snapshot of state of expansion"
-		print "-----------------------------------"
-		print "listing expanded nodes:"
-		for node_id in self.expansion_state.keys():
-			print "node ID:", node_id
-			print "  selected:", self.expansion_state[node_id]
-	#--------------------------------------------------------
-	# internal API
-	#--------------------------------------------------------
-	def __record_subtree_expansion(self, start_node_id=None):
-		"""This records node expansion states based on the item label.
-
-		A side effect of this is that identically named items can
-		become unduly synchronized in their expand state after a
-		snapshot/restore cycle.
-
-		Better choices might be
-
-			id(item.GetPyData()) or
-			item.GetPyData().get_tree_uid()
-
-		where get_tree_uid():
-
-			'[%s:%s]' % (self.__class__.__name__, id(self))
-
-		or some such. This would survive renaming of the item.
-
-		For database items it may be useful to include the
-		primary key which would - contrary to id() - survive
-		reloads from the database.
-		"""
-		# protect against empty tree where not even
-		# a root node exists
-		if not start_node_id.IsOk():
-			return True
-
-		if not self.IsExpanded(start_node_id):
-			return True
-
-		self.expansion_state[self.GetItemText(start_node_id)] = self.IsSelected(start_node_id)
-
-		child_id, cookie = self.GetFirstChild(start_node_id)
-		while child_id.IsOk():
-			self.__record_subtree_expansion(start_node_id = child_id)
-			child_id, cookie = self.GetNextChild(start_node_id, cookie)
-
-		return
-	#--------------------------------------------------------
-	def __restore_subtree_expansion(self, start_node_id=None):
-		start_node_label = self.GetItemText(start_node_id)
-		try:
-			node_selected = self.expansion_state[start_node_label]
-		except KeyError:
-			return
-
-		self.Expand(start_node_id)
-		if node_selected:
-			self.SelectItem(start_node_id)
-
-		child_id, cookie = self.GetFirstChild(start_node_id)
-		while child_id.IsOk():
-			self.__restore_subtree_expansion(start_node_id = child_id)
-			child_id, cookie = self.GetNextChild(start_node_id, cookie)
-
-		return
 # ========================================================================
 class cFileDropTarget(wx.FileDropTarget):
 	"""Generic file drop target class.
@@ -455,17 +349,22 @@ def gm_show_error(aMessage=None, aTitle = None, error=None, title=None):
 	dlg.Destroy()
 	return True
 #-------------------------------------------------------------------------
-def gm_show_info(aMessage = None, aTitle = None):
-	if aMessage is None:
-		aMessage = _('programmer forgot to specify info message')
+def gm_show_info(aMessage=None, aTitle=None, info=None, title=None):
 
-	if aTitle is None:
-		aTitle = _('generic info message')
+	if info is None:
+		info = aMessage
+	if info is None:
+		info = _('programmer forgot to specify info message')
+
+	if title is None:
+		title = aTitle
+	if title is None:
+		title = _('generic info message')
 
 	dlg = wx.MessageDialog (
 		parent = None,
-		message = aMessage,
-		caption = aTitle,
+		message = info,
+		caption = title,
 		style = wx.OK | wx.ICON_INFORMATION | wx.STAY_ON_TOP
 	)
 	dlg.ShowModal()
