@@ -39,7 +39,7 @@ from Gnumed.business import gmPerson
 from Gnumed.business import gmStaff
 from Gnumed.business import gmEMRStructItems
 from Gnumed.business import gmClinNarrative
-from Gnumed.business import gmSurgery
+from Gnumed.business import gmPraxis
 from Gnumed.business import gmForms
 from Gnumed.business import gmDocuments
 from Gnumed.business import gmPersonSearch
@@ -47,13 +47,14 @@ from Gnumed.business import gmKeywordExpansion
 
 from Gnumed.wxpython import gmListWidgets
 from Gnumed.wxpython import gmEMRStructWidgets
+from Gnumed.wxpython import gmEncounterWidgets
 from Gnumed.wxpython import gmRegetMixin
 from Gnumed.wxpython import gmPhraseWheel
 from Gnumed.wxpython import gmGuiHelpers
-from Gnumed.wxpython import gmPatSearchWidgets
 from Gnumed.wxpython import gmCfgWidgets
 from Gnumed.wxpython import gmDocumentWidgets
 from Gnumed.wxpython import gmKeywordExpansionWidgets
+from Gnumed.wxpython.gmPatSearchWidgets import set_active_patient
 
 from Gnumed.exporters import gmPatientExporter
 
@@ -79,7 +80,7 @@ def move_progress_notes_to_another_encounter(parent=None, encounters=None, episo
 
 	if encounters is None:
 		encs = emr.get_encounters(episodes = episodes)
-		encounters = gmEMRStructWidgets.select_encounters (
+		encounters = gmEncounterWidgets.select_encounters (
 			parent = parent,
 			patient = patient,
 			single_selection = False,
@@ -111,7 +112,7 @@ def move_progress_notes_to_another_encounter(parent=None, encounters=None, episo
 			columns = [_('when'), _('who'), _('type'), _('entry')],
 			choices = [
 				[	narr['date'].strftime('%x %H:%M'),
-					narr['provider'],
+					narr['modified_by'],
 					gmClinNarrative.soap_cat2l10n[narr['soap_cat']],
 					narr['narrative'].replace('\n', '/').replace('\r', '/')
 				] for narr in notes
@@ -122,7 +123,7 @@ def move_progress_notes_to_another_encounter(parent=None, encounters=None, episo
 		return True
 
 	# which encounter to move to
-	enc2move2 = gmEMRStructWidgets.select_encounters (
+	enc2move2 = gmEncounterWidgets.select_encounters (
 		parent = parent,
 		patient = patient,
 		single_selection = True
@@ -290,7 +291,7 @@ def search_narrative_across_emrs(parent=None):
 	if selected_patient is None:
 		return
 
-	wx.CallAfter(gmPatSearchWidgets.set_active_patient, patient = gmPerson.cIdentity(aPK_obj = selected_patient))
+	wx.CallAfter(set_active_patient, patient = gmPerson.cIdentity(aPK_obj = selected_patient))
 #------------------------------------------------------------
 def search_narrative_in_emr(parent=None, patient=None):
 
@@ -391,7 +392,7 @@ def export_narrative_for_medistar_import(parent=None, soap_cats=u'soapu', encoun
 	# get file name
 	aWildcard = "%s (*.txt)|*.txt|%s (*)|*" % (_("text files"), _("all files"))
 		# FIXME: make configurable
-	aDefDir = os.path.abspath(os.path.expanduser(os.path.join('~', 'gnumed','export')))
+	aDefDir = os.path.abspath(os.path.expanduser(os.path.join('~', 'gnumed')))
 		# FIXME: make configurable
 	fname = '%s-%s-%s-%s-%s.txt' % (
 		'Medistar-MD',
@@ -435,6 +436,52 @@ def export_narrative_for_medistar_import(parent=None, soap_cats=u'soapu', encoun
 
 	wx.EndBusyCursor()
 	return True
+
+#------------------------------------------------------------
+def select_narrative(parent=None, soap_cats=None, msg=None):
+
+	pat = gmPerson.gmCurrentPatient()
+	emr = pat.get_emr()
+
+	if parent is None:
+		parent = wx.GetApp().GetTopWindow()
+
+	if soap_cats is None:
+		soap_cats = u'soapu'
+	soap_cats = list(soap_cats)
+	i18n_soap_cats = [ gmClinNarrative.soap_cat2l10n[cat].upper() for cat in soap_cats ]
+
+	if msg is None:
+		msg = _('Pick the [%s] narrative you want to use.') % u'/'.join(i18n_soap_cats)
+
+	#-----------------------------------------------
+	def get_tooltip(soap):
+		return soap.format(fancy = True, width = 60)
+	#-----------------------------------------------
+	def refresh(lctrl):
+		lctrl.secondary_sort_column = 0
+		soap = emr.get_clin_narrative(soap_cats = soap_cats)
+		lctrl.set_string_items ([ [
+			gmDateTime.pydt_strftime(s['date'], '%Y %m %d'),
+			s['modified_by'],
+			gmClinNarrative.soap_cat2l10n[s['soap_cat']],
+			s['narrative'],
+			s['episode'],
+			s['health_issue']
+		] for s in soap ])
+		lctrl.set_data(soap)
+	#-----------------------------------------------
+	return gmListWidgets.get_choices_from_list (
+		parent = parent,
+		msg = msg,
+		caption = _('Picking [%s] narrative') % (u'/'.join(i18n_soap_cats)),
+		columns = [_('When'), _('Who'), _('Type'), _('Entry'), _('Episode'), _('Issue')],
+		single_selection = False,
+		can_return_empty = False,
+		refresh_callback = refresh,
+		list_tooltip_callback = get_tooltip
+	)
+
 #------------------------------------------------------------
 def select_narrative_by_issue(parent=None, soap_cats=None):
 
@@ -485,7 +532,7 @@ def select_narrative_by_issue(parent=None, soap_cats=None):
 			columns = [_('When'), _('Who'), _('Type'), _('Entry')],
 			choices = [ [
 				gmDateTime.pydt_strftime(narr['date'], '%Y %b %d  %H:%M', accuracy = gmDateTime.acc_minutes),
-				narr['provider'],
+				narr['modified_by'],
 				gmClinNarrative.soap_cat2l10n[narr['soap_cat']],
 				narr['narrative'].replace('\n', '//').replace('\r', '//')
 			] for narr in narr_for_issue ],
@@ -612,7 +659,7 @@ def select_narrative_by_episode(parent=None, soap_cats=None):
 			columns = [_('When'), _('Who'), _('Type'), _('Entry')],
 			choices = [ [
 				gmDateTime.pydt_strftime(narr['date'], '%Y %b %d  %H:%M', accuracy = gmDateTime.acc_minutes),
-				narr['provider'],
+				narr['modified_by'],
 				gmClinNarrative.soap_cat2l10n[narr['soap_cat']],
 				narr['narrative'].replace('\n', '//').replace('\r', '//')
 			] for narr in narr_for_epi ],
@@ -821,7 +868,7 @@ class cNarrativeListSelectorDlg(gmListWidgets.cGenericListSelectorDlg):
 		self._LCTRL_items.set_columns([_('when'), _('who'), _('type'), _('entry')]) #, _('Episode'), u'', _('Health Issue')])
 		# FIXME: date used should be date of encounter, not date_modified
 		self._LCTRL_items.set_string_items (
-			items = [ [narr['date'].strftime('%x %H:%M'), narr['provider'], gmClinNarrative.soap_cat2l10n[narr['soap_cat']], narr['narrative'].replace('\n', '/').replace('\r', '/')] for narr in narrative ]
+			items = [ [narr['date'].strftime('%x %H:%M'), narr['modified_by'], gmClinNarrative.soap_cat2l10n[narr['soap_cat']], narr['narrative'].replace('\n', '/').replace('\r', '/')] for narr in narrative ]
 		)
 		self._LCTRL_items.set_column_widths()
 		self._LCTRL_items.set_data(data = narrative)
@@ -1109,9 +1156,9 @@ class cSoapPluginPnl(wxgSoapPluginPnl.wxgSoapPluginPnl, gmRegetMixin.cRegetOnPai
 		# client internal signals
 		gmDispatcher.connect(signal = u'pre_patient_selection', receiver = self._on_pre_patient_selection)
 		gmDispatcher.connect(signal = u'post_patient_selection', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'episode_mod_db', receiver = self._on_episode_issue_mod_db)
-		gmDispatcher.connect(signal = u'health_issue_mod_db', receiver = self._on_episode_issue_mod_db)
-		gmDispatcher.connect(signal = u'episode_code_mod_db', receiver = self._on_episode_issue_mod_db)
+		gmDispatcher.connect(signal = u'clin.episode_mod_db', receiver = self._on_episode_issue_mod_db)
+		gmDispatcher.connect(signal = u'clin.health_issue_mod_db', receiver = self._on_episode_issue_mod_db)
+		gmDispatcher.connect(signal = u'clin.episode_code_mod_db', receiver = self._on_episode_issue_mod_db)
 	#--------------------------------------------------------
 	def _on_pre_patient_selection(self):
 		wx.CallAfter(self.__on_pre_patient_selection)
@@ -1163,7 +1210,7 @@ class cSoapPluginPnl(wxgSoapPluginPnl.wxgSoapPluginPnl, gmRegetMixin.cRegetOnPai
 		dbcfg = gmCfg.cCfgSQL()
 		allow_duplicate_editors = bool(dbcfg.get2 (
 			option = u'horstspace.soap_editor.allow_same_episode_multiple_times',
-			workplace = gmSurgery.gmCurrentPractice().active_workplace,
+			workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 			bias = u'user',
 			default = False
 		))
@@ -1290,7 +1337,7 @@ class cFancySoapEditorPnl(wxgFancySoapEditorPnl.wxgFancySoapEditorPnl):
 		dbcfg = gmCfg.cCfgSQL()
 		auto_open_recent_problems = bool(dbcfg.get2 (
 			option = u'horstspace.soap_editor.auto_open_latest_episodes',
-			workplace = gmSurgery.gmCurrentPractice().active_workplace,
+			workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 			bias = u'user',
 			default = True
 		))
@@ -1348,7 +1395,7 @@ class cFancySoapEditorPnl(wxgFancySoapEditorPnl.wxgFancySoapEditorPnl):
 #			'pk_type': enc['pk_type'],
 #			'reason_for_encounter': gmTools.none_if(self._TCTRL_rfe.GetValue().strip(), u''),
 #			'assessment_of_encounter': gmTools.none_if(self._TCTRL_aoe.GetValue().strip(), u''),
-#			'pk_location': enc['pk_location'],
+#			'pk_location': enc['pk_org_unit'],
 #			'pk_patient': enc['pk_patient'],
 #			'pk_generic_codes_rfe': self._PRW_rfe_codes.GetData(),
 #			'pk_generic_codes_aoe': self._PRW_aoe_codes.GetData(),
@@ -1369,11 +1416,11 @@ class cFancySoapEditorPnl(wxgFancySoapEditorPnl.wxgFancySoapEditorPnl):
 		gmDispatcher.send(signal = u'register_pre_exit_callback', callback = self._pre_exit_callback)
 
 		# client internal signals
-		gmDispatcher.connect(signal = u'doc_mod_db', receiver = self._on_doc_mod_db)			# visual progress notes
+		gmDispatcher.connect(signal = u'blobs.doc_med_mod_db', receiver = self._on_doc_mod_db)			# visual progress notes
 		gmDispatcher.connect(signal = u'current_encounter_modified', receiver = self._on_current_encounter_modified)
 		gmDispatcher.connect(signal = u'current_encounter_switched', receiver = self._on_current_encounter_switched)
-		gmDispatcher.connect(signal = u'rfe_code_mod_db', receiver = self._on_encounter_code_modified)
-		gmDispatcher.connect(signal = u'aoe_code_mod_db', receiver = self._on_encounter_code_modified)
+		gmDispatcher.connect(signal = u'clin.rfe_code_mod_db', receiver = self._on_encounter_code_modified)
+		gmDispatcher.connect(signal = u'clin.aoe_code_mod_db', receiver = self._on_encounter_code_modified)
 	#--------------------------------------------------------
 	def _pre_selection_callback(self):
 		"""Another patient is about to be activated.
@@ -1460,7 +1507,7 @@ class cFancySoapEditorPnl(wxgFancySoapEditorPnl.wxgFancySoapEditorPnl):
 		event.Skip()
 	#--------------------------------------------------------
 	def _on_save_note_under_button_pressed(self, event):
-		encounter = gmEMRStructWidgets.select_encounters (
+		encounter = gmEncounterWidgets.select_encounters (
 			parent = self,
 			patient = self.__pat,
 			single_selection = True
@@ -1948,7 +1995,7 @@ class cSoapNoteExpandoEditAreaPnl(wxgSoapNoteExpandoEditAreaPnl.wxgSoapNoteExpan
 		for field in self.soap_fields:
 			wx_expando.EVT_ETC_LAYOUT_NEEDED(field, field.GetId(), self._on_expando_needs_layout)
 		wx_expando.EVT_ETC_LAYOUT_NEEDED(self._TCTRL_episode_summary, self._TCTRL_episode_summary.GetId(), self._on_expando_needs_layout)
-		gmDispatcher.connect(signal = u'doc_page_mod_db', receiver = self._refresh_visual_soap)
+		gmDispatcher.connect(signal = u'blobs.doc_obj_mod_db', receiver = self._refresh_visual_soap)
 	#--------------------------------------------------------
 	def _refresh_visual_soap(self):
 		wx.CallAfter(self.refresh_visual_soap)
@@ -2276,7 +2323,7 @@ def edit_visual_progress_note(filename=None, episode=None, discard_unmodified=Fa
 	dbcfg = gmCfg.cCfgSQL()
 	cmd = dbcfg.get2 (
 		option = u'external.tools.visual_soap_editor_cmd',
-		workplace = gmSurgery.gmCurrentPractice().active_workplace,
+		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 		bias = 'user'
 	)
 
@@ -2586,7 +2633,7 @@ class cSimpleSoapPluginPnl(wxgSimpleSoapPluginPnl.wxgSimpleSoapPluginPnl, gmRege
 			self._CHBOX_filter_by_problem.Refresh()
 
 		if not self._CHBOX_filter_by_problem.IsChecked():
-			self._TCTRL_journal.SetValue(self.__curr_pat.emr.format_summary(dob = self.__curr_pat['dob']))
+			self._TCTRL_journal.SetValue(self.__curr_pat.emr.format_summary())
 			return
 
 		if epi is None:
@@ -2601,8 +2648,8 @@ class cSimpleSoapPluginPnl(wxgSimpleSoapPluginPnl.wxgSimpleSoapPluginPnl, gmRege
 		# client internal signals
 		gmDispatcher.connect(signal = u'pre_patient_selection', receiver = self._on_pre_patient_selection)
 		gmDispatcher.connect(signal = u'post_patient_selection', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'episode_mod_db', receiver = self._on_episode_issue_mod_db)
-		gmDispatcher.connect(signal = u'health_issue_mod_db', receiver = self._on_episode_issue_mod_db)
+		gmDispatcher.connect(signal = u'clin.episode_mod_db', receiver = self._on_episode_issue_mod_db)
+		gmDispatcher.connect(signal = u'clin.health_issue_mod_db', receiver = self._on_episode_issue_mod_db)
 
 		# synchronous signals
 		self.__curr_pat.register_pre_selection_callback(callback = self._pre_selection_callback)
@@ -2739,13 +2786,22 @@ if __name__ == '__main__':
 	#----------------------------------------
 	def test_select_narrative_from_episodes():
 		pat = gmPersonSearch.ask_for_patient()
-		gmPatSearchWidgets.set_active_patient(patient = pat)
+		set_active_patient(patient = pat)
 		app = wx.PyWidgetTester(size = (200, 200))
 		sels = select_narrative_from_episodes_new()
 		print "selected:"
 		for sel in sels:
 			print sel
 	#----------------------------------------
+	def test_select_narrative():
+		pat = gmPersonSearch.ask_for_patient()
+		set_active_patient(patient = pat)
+		app = wx.PyWidgetTester(size = (200, 200))
+		sels = select_narrative(parent=None, soap_cats = None)
+		print "selected:"
+		for sel in sels:
+			print sel
+	#----------------------------------------
 	def test_cSoapNoteExpandoEditAreaPnl():
 		pat = gmPersonSearch.ask_for_patient()
 		application = wx.PyWidgetTester(size=(800,500))
@@ -2758,7 +2814,7 @@ if __name__ == '__main__':
 		if patient is None:
 			print "No patient. Exiting gracefully..."
 			return
-		gmPatSearchWidgets.set_active_patient(patient=patient)
+		set_active_patient(patient=patient)
 
 		application = wx.PyWidgetTester(size=(800,500))
 		soap_input = cSoapPluginPnl(application.frame, -1)
@@ -2766,7 +2822,8 @@ if __name__ == '__main__':
 		soap_input._schedule_data_reget()
 		application.MainLoop()
 	#----------------------------------------
-	test_select_narrative_from_episodes()
+	#test_select_narrative_from_episodes()
+	test_select_narrative()
 	#test_cSoapNoteExpandoEditAreaPnl()
 	#test_cSoapPluginPnl()
 
