@@ -17,7 +17,9 @@ if __name__ == '__main__':
 from Gnumed.pycommon import gmTools
 from Gnumed.pycommon import gmMatchProvider
 from Gnumed.pycommon import gmDispatcher
+
 from Gnumed.business import gmOrganization
+
 from Gnumed.wxpython import gmListWidgets
 from Gnumed.wxpython import gmEditArea
 from Gnumed.wxpython import gmPhraseWheel
@@ -44,6 +46,47 @@ def edit_org_unit(parent=None, org_unit=None, single_entry=False, org=None):
 		return True
 	dlg.Destroy()
 	return False
+
+#============================================================
+def select_org_unit(parent=None, msg=None, no_parent=False):
+
+	if no_parent:
+		parent = None
+	else:
+		if parent is None:
+			parent = wx.GetApp().GetTopWindow()
+
+	#--------------------
+	def new():
+		manage_orgs(parent = parent, no_parent = no_parent)
+		return True
+	#--------------------
+	def refresh(lctrl):
+		units = gmOrganization.get_org_units(order_by = 'organization, unit, l10n_unit_category')
+		items = [ [
+			u['organization'],
+			u['unit'],
+			gmTools.coalesce(u['l10n_unit_category'], u''),
+			u['pk_org_unit']
+		] for u in units ]
+
+		lctrl.set_string_items(items = items)
+		lctrl.set_data(data = units)
+	#--------------------
+	if msg is None:
+		msg = _("Organizations and units thereof.\n")
+
+	return gmListWidgets.get_choices_from_list (
+		parent = parent,
+		msg = msg,
+		caption = _('Unit selection ...'),
+		columns = [_('Organization'), _('Unit'), _('Unit type'), '#'],
+		can_return_empty = False,
+		single_selection = True,
+		refresh_callback = refresh,
+		new_callback = new
+	)
+
 #============================================================
 class cOrgUnitPhraseWheel(gmPhraseWheel.cPhraseWheel):
 
@@ -162,10 +205,16 @@ class cOrgUnitsManagerPnl(gmListWidgets.cGenericListManagerPnl):
 	# internal helpers
 	#--------------------------------------------------------
 	def __init_ui(self):
-		self._LCTRL_items.SetToolTipString(_('Units (sites, parts, departments, branches, ...) of organizations registered in GNUmed.'))
 		self._LCTRL_items.set_columns(columns = [ _('Organizational Unit'), _('Unit Category'), u'#' ])
+		self._LCTRL_items.SetToolTipString(_('Units (sites, parts, departments, branches, ...) of organizations registered in GNUmed.'))
+		self._LCTRL_items.item_tooltip_callback = self.get_tooltip
 		#self._LCTRL_items.set_column_widths(widths = [wx.LIST_AUTOSIZE, wx.LIST_AUTOSIZE, wx.LIST_AUTOSIZE])
 	#--------------------------------------------------------
+	def get_tooltip(self, unit):
+		if unit is None:
+			return _('Units (sites, parts, departments, branches, ...) of organizations registered in GNUmed.')
+		return u'\n'.join(unit.format(with_address = True, with_org = True, with_comms = True))
+	#--------------------------------------------------------
 	def __refresh(self):
 
 		msg_template = _('Units of: %s')
@@ -197,6 +246,11 @@ class cOrgUnitsManagerPnl(gmListWidgets.cGenericListManagerPnl):
 
 		self._LCTRL_items.set_string_items(items)
 		self._LCTRL_items.set_data(units)
+
+		for idx in range(len(units)):
+			unit = units[idx]
+			if unit['is_praxis_branch']:
+				self._LCTRL_items.SetItemTextColour(idx, col=wx.NamedColour('RED'))
 	#--------------------------------------------------------
 	# properties
 	#--------------------------------------------------------
@@ -387,10 +441,10 @@ class cOrgUnitAddressPnl(wxgOrgUnitAddressPnl.wxgOrgUnitAddressPnl):
 		self.__refresh()
 	#--------------------------------------------------------
 	def _on_add_new_address_button_pressed(self, event):
-		ea = gmAddressWidgets.cAddressEditAreaPnl(self, -1)
+		ea = gmAddressWidgets.cAddressEAPnl(self, -1)
 		ea.address_holder = self.__unit
 		ea.type_is_editable = False
-		dlg = gmEditArea.cGenericEditAreaDlg(self, -1, edit_area = ea)
+		dlg = gmEditArea.cGenericEditAreaDlg2(self, -1, edit_area = ea)
 		dlg.SetTitle(_('Adding new address'))
 		if dlg.ShowModal() != wx.ID_OK:
 			return False
@@ -446,13 +500,17 @@ class cOrgUnitAddressPnl(wxgOrgUnitAddressPnl.wxgOrgUnitAddressPnl):
 #============================================================
 # organizations API
 #------------------------------------------------------------
-def manage_orgs(parent=None):
+def manage_orgs(parent=None, no_parent=False):
 
-	if parent is None:
-		parent = wx.GetApp().GetTopWindow()
+	if no_parent:
+		parent = None
+	else:
+		if parent is None:
+			parent = wx.GetApp().GetTopWindow()
 
 	dlg = cOrganizationManagerDlg(parent, -1)
 	dlg.ShowModal()
+	dlg.Destroy()
 #============================================================
 def edit_org(parent=None, org=None, single_entry=False):
 	ea = cOrganizationEAPnl(parent = parent, id = -1)
@@ -667,6 +725,12 @@ class cOrganizationsManagerPnl(gmListWidgets.cGenericListManagerPnl):
 		items = [ [o['organization'], o['l10n_category'], o['pk_org']] for o in orgs ]
 		self._LCTRL_items.set_string_items(items)
 		self._LCTRL_items.set_data(orgs)
+
+		for idx in range(len(orgs)):
+			org = orgs[idx]
+			if org['is_praxis']:
+				self._LCTRL_items.SetItemTextColour(idx, col=wx.NamedColour('RED'))
+				break
 	#--------------------------------------------------------
 	# event handlers
 	#--------------------------------------------------------
@@ -685,9 +749,15 @@ class cOrganizationsManagerPnl(gmListWidgets.cGenericListManagerPnl):
 	# internal helpers
 	#--------------------------------------------------------
 	def __init_ui(self):
-		self._LCTRL_items.SetToolTipString(_('Organizations registered in GNUmed.'))
 		self._LCTRL_items.set_columns(columns = [_('Organization'), _('Category'), u'#'])
+		self._LCTRL_items.SetToolTipString(_('Organizations registered in GNUmed.'))
+		self._LCTRL_items.item_tooltip_callback = self.get_tooltip
 		#self._LCTRL_items.set_column_widths(widths = [wx.LIST_AUTOSIZE, wx.LIST_AUTOSIZE, wx.LIST_AUTOSIZE])
+	#--------------------------------------------------------
+	def get_tooltip(self, org):
+		if org is None:
+			return _('Organizations registered in GNUmed.')
+		return org.format()
 #============================================================
 from Gnumed.wxGladeWidgets import wxgOrganizationManagerDlg
 
