@@ -34,6 +34,7 @@ from Gnumed.wxpython import gmContactWidgets
 from Gnumed.wxpython import gmMedicationWidgets
 from Gnumed.wxpython import gmEditArea
 from Gnumed.wxpython import gmEMRStructWidgets
+from Gnumed.wxpython import gmEncounterWidgets
 from Gnumed.wxpython import gmFamilyHistoryWidgets
 from Gnumed.wxpython import gmVaccWidgets
 from Gnumed.wxpython import gmDocumentWidgets
@@ -121,29 +122,30 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 		gmDispatcher.connect(signal = u'post_patient_selection', receiver = self._on_post_patient_selection)
 
 		# database change signals
-		gmDispatcher.connect(signal = u'identity_mod_db', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'name_mod_db', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'comm_channel_mod_db', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'job_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'dem.identity_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'dem.names_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'dem.comm_channel_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'dem.job_mod_db', receiver = self._on_post_patient_selection)
 		# no signal for external IDs yet
 		# no signal for address yet
 		#gmDispatcher.connect(signal = u'current_encounter_modified', receiver = self._on_current_encounter_modified)
 		#gmDispatcher.connect(signal = u'current_encounter_switched', receiver = self._on_current_encounter_switched)
 
-		gmDispatcher.connect(signal = u'episode_mod_db', receiver = self._on_episode_issue_mod_db)
-		gmDispatcher.connect(signal = u'health_issue_mod_db', receiver = self._on_episode_issue_mod_db)
+		gmDispatcher.connect(signal = u'clin.episode_mod_db', receiver = self._on_episode_issue_mod_db)
+		gmDispatcher.connect(signal = u'clin.health_issue_mod_db', receiver = self._on_episode_issue_mod_db)
 
-		gmDispatcher.connect(signal = u'substance_intake_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'clin.substance_intake_mod_db', receiver = self._on_post_patient_selection)
 
-		gmDispatcher.connect(signal = u'hospital_stay_mod_db', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'family_history_mod_db', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'procedure_mod_db', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'vacc_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'clin.hospital_stay_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'clin.family_history_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'clin.procedure_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'clin.vaccination_mod_db', receiver = self._on_post_patient_selection)
+		#gmDispatcher.connect(signal = u'gm_table_mod', receiver = self._on_post_patient_selection)
 
-		gmDispatcher.connect(signal = u'message_inbox_mod_db', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'test_result_mod_db', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'reviewed_test_results_mod_db', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'doc_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'dem.message_inbox_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'clin.test_result_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'clin.reviewed_test_results_mod_db', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'blobs.doc_med_mod_db', receiver = self._on_post_patient_selection)
 
 		# synchronous signals
 #		self.__pat.register_pre_selection_callback(callback = self._pre_selection_callback)
@@ -201,8 +203,9 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			self._LCTRL_results.set_data(data = [])
 			return
 
+		now = gmDateTime.pydt_now_here()
 		list_items.append(_('Latest: %s ago (%s %s %s %s%s)') % (
-			gmDateTime.format_interval_medically(gmDateTime.pydt_now_here() - most_recent['clin_when']),
+			gmDateTime.format_interval_medically(now - most_recent['clin_when']),
 			most_recent['unified_abbrev'],
 			most_recent['unified_val'],
 			most_recent['val_unit'],
@@ -211,12 +214,13 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 		))
 		list_data.append(most_recent)
 		most_recent_needs_red = False
-		if most_recent['is_technically_abnormal'] is True:
+		#if most_recent['is_technically_abnormal'] is True:
+		if most_recent.is_considered_abnormal is True:
 			if most_recent['is_clinically_relevant']:
 				most_recent_needs_red = True
-		else:
-			if most_recent['abnormality_indicator'] not in [None, u'']:
-				most_recent_needs_red = True
+#		else:
+#			if most_recent['abnormality_indicator'] not in [None, u'']:
+#				most_recent_needs_red = True
 
 		unsigned = emr.get_unsigned_results(order_by = u"(trim(coalesce(abnormality_indicator), '') <> '') DESC NULLS LAST, unified_abbrev")
 		no_of_reds = 0
@@ -449,7 +453,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 		first = emr.get_first_encounter()
 		if first is not None:
 			list_items.append (
-				_('first: %s, %s') % (
+				_('first (in GMd): %s, %s') % (
 					gmDateTime.pydt_strftime (
 						first['started'],
 						format = '%Y %b %d',
@@ -526,7 +530,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			# <ctrl> down ?
 			if wx.GetKeyState(wx.WXK_CONTROL):
 				if isinstance(data, gmEMRStructItems.cEncounter):
-					gmEMRStructWidgets.edit_encounter(parent = self, encounter = data)
+					gmEncounterWidgets.edit_encounter(parent = self, encounter = data)
 					return
 
 		if type(data) == type({}):
@@ -538,14 +542,14 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 				wx.CallAfter(gmEMRStructWidgets.manage_hospital_stays, parent = self)
 				return
 
-		wx.CallAfter(gmEMRStructWidgets.manage_encounters, parent = self, ignore_OK_button = False)
+		wx.CallAfter(gmEncounterWidgets.manage_encounters, parent = self, ignore_OK_button = False)
 	#-----------------------------------------------------
 	#-----------------------------------------------------
 	def __refresh_history(self, patient=None):
 		emr = patient.get_emr()
 
-		list_items = []
-		list_data = []
+		sort_key_list = []
+		data = {}
 
 		issues = [
 			i for i in emr.get_health_issues()
@@ -555,57 +559,81 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 			last_encounter = emr.get_last_encounter(issue_id = issue['pk_health_issue'])
 			if last_encounter is None:
 				last = issue['modified_when'].strftime('%m/%Y')
+				sort_key = u'%s::%s' % (gmDateTime.pydt_strftime(issue['modified_when'], format = '%Y %m %d %H %M %S'), issue['pk_health_issue'])
 			else:
 				last = last_encounter['last_affirmed'].strftime('%m/%Y')
-			list_items.append(u'%s %s' % (last, issue['description']))
-			list_data.append(issue)
+				sort_key = u'%s::%s' % (gmDateTime.pydt_strftime(last_encounter['last_affirmed'], format = '%Y %m %d %H %M %S'), issue['pk_health_issue'])
+			sort_key_list.append(sort_key)
+			data[sort_key] = [u'%s %s' % (last, issue['description']), issue]
 		del issues
 
 		fhxs = emr.get_family_history()
 		for fhx in fhxs:
-			list_items.append(u'%s: %s%s' % (
+			sort_key = u'0000 %s::%s' % (fhx['l10n_relation'], fhx['pk_family_history'])
+			#gmDateTime.pydt_strftime(fhx['when_known_to_patient'], format = '%Y %m %d %H %M %S')
+			label = u'%s: %s%s' % (
 				fhx['l10n_relation'],
 				fhx['condition'],
 				gmTools.coalesce(fhx['age_noted'], u'', u' (@ %s)')
-			))
-			list_data.append(fhx)
+			)
+			sort_key_list.append(sort_key)
+			data[sort_key] = [label, fhx]
 		del fhxs
 
 		stays = emr.get_hospital_stays()
 		for stay in stays:
-			if stay['discharge'] is not None:
-				discharge = u''
-			else:
+			if stay['discharge'] is None:
 				discharge = gmTools.u_ellipsis
-			list_items.append(u'%s%s %s: %s' % (
+				sort_key = u'%s::%s' % (gmDateTime.pydt_strftime(stay['admission'], format = '%Y %m %d %H %M %S'), stay['pk_hospital_stay'])
+			else:
+				discharge = u''
+				sort_key = u'%s::%s' % (gmDateTime.pydt_strftime(stay['discharge'], format = '%Y %m %d %H %M %S'), stay['pk_hospital_stay'])
+			label = u'%s%s %s: %s' % (
 				gmDateTime.pydt_strftime(stay['admission'], format = '%Y %b %d'),
 				discharge,
 				stay['hospital'],
 				stay['episode']
-			))
-			list_data.append(stay)
+			)
+			sort_key_list.append(sort_key)
+			data[sort_key] = [label, stay]
 		del stays
 
 		procs = emr.get_performed_procedures()
 		for proc in procs:
-			list_items.append(u'%s%s %s' % (
+			if proc['is_ongoing']:
+				sort_key = u'%s::%s' % (gmDateTime.pydt_strftime(proc['clin_when'], format = '%Y %m %d %H %M %S'), proc['pk_procedure'])
+			else:
+				sort_key = u'%s::%s' % (gmDateTime.pydt_strftime(proc['clin_end'], format = '%Y %m %d %H %M %S'), proc['pk_procedure'])
+			label = u'%s%s %s' % (
 				gmDateTime.pydt_strftime(proc['clin_when'], format = '%Y %b %d'),
 				gmTools.bool2subst(proc['is_ongoing'], gmTools.u_ellipsis, u'', u''),
 				proc['performed_procedure']
-			))
-			list_data.append(proc)
+			)
+			sort_key_list.append(sort_key)
+			data[sort_key] = [label, proc]
 		del procs
 
 		vaccs = emr.get_latest_vaccinations()
 		for ind, tmp in vaccs.items():
 			tmp, vacc = tmp
-			list_items.append(_('%s Vacc: %s') % (
-				gmDateTime.pydt_strftime(vacc['date_given'], format = '%Y %b %d'),
+			sort_key = u'%s::%s' % (gmDateTime.pydt_strftime(vacc['date_given'], format = '%Y %m %d %H %M %S'), vacc['pk_vaccination'])
+			label = _('%s Vacc: %s') % (
+				gmDateTime.pydt_strftime(vacc['date_given'], format = '%Y %b'),
 				ind
-			))
-			list_data.append(vacc)
+			)
+			sort_key_list.append(sort_key)
+			data[sort_key] = [label, vacc]
 		del vaccs
 
+		sort_key_list.sort()
+		sort_key_list.reverse()
+		list_items = []
+		list_data = []
+		for key in sort_key_list:
+			label, item = data[key]
+			list_items.append(label)
+			list_data.append(item)
+
 		self._LCTRL_history.set_string_items(items = list_items)
 		self._LCTRL_history.set_data(data = list_data)
 	#-----------------------------------------------------
@@ -688,7 +716,7 @@ class cPatientOverviewPnl(wxgPatientOverviewPnl.wxgPatientOverviewPnl, gmRegetMi
 	def __refresh_meds(self, patient=None):
 		# list by brand or substance:
 		emr = patient.get_emr()
-		intakes = emr.get_current_substance_intake(include_inactive = False, include_unapproved = True, order_by = u'substance')
+		intakes = emr.get_current_substance_intakes(include_inactive = False, include_unapproved = True, order_by = u'substance')
 
 		list_items = []
 		multi_brands_already_seen = []
