@@ -34,13 +34,17 @@ from Gnumed.pycommon import gmNetworkTools
 from Gnumed.business import gmPerson
 from Gnumed.business import gmStaff
 from Gnumed.business import gmKVK
-from Gnumed.business import gmSurgery
+from Gnumed.business import gmPraxis
 from Gnumed.business import gmCA_MSVA
 from Gnumed.business import gmPersonSearch
 from Gnumed.business import gmProviderInbox
 
-from Gnumed.wxpython import gmGuiHelpers, gmDemographicsWidgets, gmAuthWidgets
-from Gnumed.wxpython import gmRegetMixin, gmPhraseWheel, gmEditArea
+from Gnumed.wxpython import gmGuiHelpers
+from Gnumed.wxpython import gmAuthWidgets
+from Gnumed.wxpython import gmRegetMixin
+from Gnumed.wxpython import gmEditArea
+from Gnumed.wxpython import gmPhraseWheel
+from Gnumed.wxpython.gmPersonCreationWidgets import create_new_person
 
 
 _log = logging.getLogger('gm.person')
@@ -520,7 +524,7 @@ def load_persons_from_kvks():
 	dbcfg = gmCfg.cCfgSQL()
 	kvk_dir = os.path.abspath(os.path.expanduser(dbcfg.get2 (
 		option = 'DE.KVK.spool_dir',
-		workplace = gmSurgery.gmCurrentPractice().active_workplace,
+		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 		bias = 'workplace',
 		default = u'/var/spool/kvkd/'
 	)))
@@ -792,7 +796,7 @@ class cPersonSearchCtrl(wx.TextCtrl):
 			dbcfg = gmCfg.cCfgSQL()
 			search_immediately = bool(dbcfg.get2 (
 				option = 'patient_search.external_sources.immediately_search_if_single_source',
-				workplace = gmSurgery.gmCurrentPractice().active_workplace,
+				workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 				bias = 'user',
 				default = 0
 			))
@@ -869,7 +873,7 @@ class cPersonSearchCtrl(wx.TextCtrl):
 			if dlg.ShowModal() != wx.ID_NO:
 				return
 
-			success = gmDemographicsWidgets.create_new_person(activate = True)
+			success = create_new_person(activate = True)
 			if success:
 				self.person = gmPerson.gmCurrentPatient()
 			else:
@@ -973,14 +977,16 @@ def _check_for_provider_chart_access(patient=None):
 		gmProviderInbox.create_inbox_message (
 			staff = patient.staff_id,
 			message_type = _('Privacy notice'),
-			subject = _('Your chart has been accessed by %s.') % prov,
+			message_category = u'administrative',
+			subject = _('%s: Your chart has been accessed by %s.') % (pat, prov),
 			patient = patient.ID
 		)
 		# notify /me about the staff member notification
 		gmProviderInbox.create_inbox_message (
 			staff = curr_prov['pk_staff'],
 			message_type = _('Privacy notice'),
-			subject = _('Staff member %s has been notified of your chart access.') % pat
+			message_category = u'administrative',
+			subject = _('%s: Staff member %s has been notified of your chart access.') % (prov, pat)
 		)
 
 	return proceed
@@ -993,7 +999,7 @@ def _check_birthday(patient=None):
 	dbcfg = gmCfg.cCfgSQL()
 	dob_distance = dbcfg.get2 (
 		option = u'patient_search.dob_warn_interval',
-		workplace = gmSurgery.gmCurrentPractice().active_workplace,
+		workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 		bias = u'user',
 		default = u'1 week'
 	)
@@ -1063,7 +1069,7 @@ class cActivePatientSelector(cPersonSearchCtrl):
 		self.__always_dismiss_on_search = bool ( 
 			cfg.get2 (
 				option = 'patient_search.always_dismiss_previous_patient',
-				workplace = gmSurgery.gmCurrentPractice().active_workplace,
+				workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 				bias = 'user',
 				default = 0
 			)
@@ -1072,7 +1078,7 @@ class cActivePatientSelector(cPersonSearchCtrl):
 		self.__always_reload_after_search = bool (
 			cfg.get2 (
 				option = 'patient_search.always_reload_new_patient',
-				workplace = gmSurgery.gmCurrentPractice().active_workplace,
+				workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 				bias = 'user',
 				default = 0
 			)
@@ -1129,8 +1135,8 @@ class cActivePatientSelector(cPersonSearchCtrl):
 	def __register_events(self):
 		# client internal signals
 		gmDispatcher.connect(signal = u'post_patient_selection', receiver = self._on_post_patient_selection)
-		gmDispatcher.connect(signal = u'name_mod_db', receiver = self._on_name_identity_change)
-		gmDispatcher.connect(signal = u'identity_mod_db', receiver = self._on_name_identity_change)
+		gmDispatcher.connect(signal = u'dem.names_mod_db', receiver = self._on_name_identity_change)
+		gmDispatcher.connect(signal = u'dem.identity_mod_db', receiver = self._on_name_identity_change)
 
 		gmDispatcher.connect(signal = 'patient_locked', receiver = self._on_post_patient_selection)
 		gmDispatcher.connect(signal = 'patient_unlocked', receiver = self._on_post_patient_selection)
