@@ -3,9 +3,6 @@
 Design by Richard Terry and Ian Haywood.
 """
 #====================================================================
-# $Source: /home/ncq/Projekte/cvs2git/vcs-mirror/gnumed/gnumed/client/wxpython/gmResizingWidgets.py,v $
-# $Id: gmResizingWidgets.py,v 1.55 2009-03-10 14:24:15 ncq Exp $
-__version__ = "$Revision: 1.55 $"
 __author__ = "Ian Haywood, Karsten Hilbert, Richard Terry"
 __license__ = 'GPL v2 or later (details at http://www.gnu.org)'
 
@@ -17,10 +14,10 @@ import wx.stc
 
 
 from Gnumed.pycommon import gmI18N, gmDispatcher, gmPG2
+from Gnumed.business import gmKeywordExpansion
 from Gnumed.wxpython import gmGuiHelpers, gmTimer
 
 _log = logging.getLogger('gm.ui')
-_log.info(__version__)
 
 STYLE_ERROR=1
 STYLE_TEXT=2
@@ -503,7 +500,7 @@ class cResizingSTC(wx.stc.StyledTextCtrl):
 		if keyword == u'$$steffi':			# Easter Egg ;-)
 			expansion = u'Hai, play! Versucht das!  (Keks dazu?)  :-)'
 		else:
-			expansion = gmPG2.expand_keyword(keyword = keyword)
+			expansion = gmKeywordExpansion.expand_keyword(keyword = keyword)
 
 		if expansion is None:
 			return
@@ -684,7 +681,7 @@ class cResizingSTC(wx.stc.StyledTextCtrl):
 
 			line, caret_pos = self.GetCurLine()
 			word = self.__keyword_separators.split(line[:caret_pos])[-1]
-			if (word not in [ r[0] for r in gmPG2.get_text_expansion_keywords() ]) and (word != u'$$steffi'):		# Easter Egg ;-)
+			if (word not in [ r[0] for r in gmKeywordExpansion.get_textual_expansion_keywords() ]) and (word != u'$$steffi'):		# Easter Egg ;-)
 				evt.Skip()
 				return
 
