@@ -16,7 +16,7 @@ import wx
 # GNUmed
 from Gnumed.pycommon import gmDispatcher, gmI18N, gmExceptions, gmMatchProvider, gmTools, gmCfg
 from Gnumed.wxpython import gmResizingWidgets, gmPhraseWheel, gmEMRStructWidgets, gmGuiHelpers, gmRegetMixin, gmEditArea, gmPatSearchWidgets
-from Gnumed.business import gmPerson, gmEMRStructItems, gmSOAPimporter, gmSurgery, gmPersonSearch, gmStaff
+from Gnumed.business import gmPerson, gmEMRStructItems, gmSOAPimporter, gmPraxis, gmPersonSearch, gmStaff
 
 _log = logging.getLogger('gm.ui')
 _log.info(__version__)
@@ -526,8 +526,8 @@ class cNotebookedProgressNoteInputPanel(wx.Panel):
 
 		# client internal signals
 		gmDispatcher.connect(signal='post_patient_selection', receiver=self._on_post_patient_selection)
-		gmDispatcher.connect(signal = 'episode_mod_db', receiver = self._on_episode_issue_mod_db)
-		gmDispatcher.connect(signal = 'health_issue_mod_db', receiver = self._on_episode_issue_mod_db)
+		gmDispatcher.connect(signal = 'clin.episode_mod_db', receiver = self._on_episode_issue_mod_db)
+		gmDispatcher.connect(signal = 'clin.health_issue_mod_db', receiver = self._on_episode_issue_mod_db)
 	#--------------------------------------------------------
 	def _on_post_patient_selection(self):
 		"""Patient changed."""
@@ -571,7 +571,7 @@ class cNotebookedProgressNoteInputPanel(wx.Panel):
 			dbcfg = gmCfg.cCfgSQL()
 			value = bool(dbcfg.get2 (
 				option = u'horstspace.soap_editor.allow_same_episode_multiple_times',
-				workplace = gmSurgery.gmCurrentPractice().active_workplace,
+				workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 				bias = u'user',
 				default = False
 			))
@@ -1128,7 +1128,7 @@ if __name__ == "__main__":
 					# FIXME: add more data such as doctor sig
 					label_txt = default_labels[narrative['soap_cat']]
 				except:
-					label_txt = narrative['soap_cat']				
+					label_txt = narrative['soap_cat']
 				line = cSOAPLineDef()
 				line.label = label_txt
 				line.text = narrative['narrative']
