@@ -27,7 +27,7 @@ from Gnumed.pycommon import gmPrinting
 
 from Gnumed.business import gmPerson
 from Gnumed.business import gmVaccination
-from Gnumed.business import gmSurgery
+from Gnumed.business import gmPraxis
 from Gnumed.business import gmProviderInbox
 
 from Gnumed.wxpython import gmPhraseWheel
@@ -573,64 +573,28 @@ def print_vaccinations(parent=None):
 	if parent is None:
 		parent = wx.GetApp().GetTopWindow()
 
-	# 1) get template
-	template = gmFormWidgets.manage_form_templates (
+	vaccs_printout = gmFormWidgets.generate_form_from_template (
 		parent = parent,
-		active_only = True,
 		template_types = [
 			u'Medical statement',
 			u'vaccination report',
 			u'vaccination record',
 			u'reminder'
-		]
+		],
+		edit = False
 	)
 
-	if template is None:
-		gmDispatcher.send(signal = 'statustext', msg = _('No vaccination document template selected.'), beep = False)
-		return None
-
-	# 2) process template
-	try:
-		vaccs_printout = template.instantiate()
-	except KeyError:
-		_log.exception('cannot instantiate vaccinations printout template [%s]', template)
-		gmGuiHelpers.gm_show_error (
-			aMessage = _('Invalid vaccinations printout template [%s - %s (%s)]') % (name, ver, template['engine']),
-			aTitle = _('Printing vaccinations')
-		)
+	if vaccs_printout is None:
 		return False
 
-	ph = gmMacro.gmPlaceholderHandler()
-	#ph.debug = True
-	vaccs_printout.substitute_placeholders(data_source = ph)
-	pdf_name = vaccs_printout.generate_output()
-	if pdf_name is None:
-		gmGuiHelpers.gm_show_error (
-			aMessage = _('Error generating the vaccinations printout.'),
-			aTitle = _('Printing vaccinations')
-		)
-		return False
-
-	# 3) print template
-	printed = gmPrinting.print_files(filenames = [pdf_name], jobtype = 'vaccinations')
-	if not printed:
-		gmGuiHelpers.gm_show_error (
-			aMessage = _('Error printing vaccinations.'),
-			aTitle = _('Printing vaccinations')
-		)
-		return False
-
-	pat = gmPerson.gmCurrentPatient()
-	emr = pat.get_emr()
-	epi = emr.add_episode(episode_name = 'administration', is_open = False)
-	emr.add_clin_narrative (
-		soap_cat = None,
-		note = _('vaccinations printed from template [%s - %s]') % (template['name_long'], template['external_version']),
-		episode = epi
+	return gmFormWidgets.act_on_generated_forms (
+		parent = parent,
+		forms = [vaccs_printout],
+		jobtype = 'vaccinations',
+		episode_name = u'administrative',
+		review_copy_as_normal = True
 	)
 
-	return True
-
 #----------------------------------------------------------------------
 def edit_vaccination(parent=None, vaccination=None, single_entry=True):
 	ea = cVaccinationEAPnl(parent = parent, id = -1)
@@ -659,7 +623,7 @@ def manage_vaccinations(parent=None):
 		dbcfg = gmCfg.cCfgSQL()
 		url = dbcfg.get2 (
 			option = 'external.urls.vaccination_plans',
-			workplace = gmSurgery.gmCurrentPractice().active_workplace,
+			workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 			bias = 'user',
 			default = u'http://www.bundesaerztekammer.de/downloads/STIKOEmpf2011.pdf'
 		)
@@ -1017,7 +981,7 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 		dbcfg = gmCfg.cCfgSQL()
 		url = dbcfg.get2 (
 			option = u'external.urls.report_vaccine_ADR',
-			workplace = gmSurgery.gmCurrentPractice().active_workplace,
+			workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 			bias = u'user',
 			default = u'http://www.pei.de/cln_042/SharedDocs/Downloads/fachkreise/uaw/meldeboegen/b-ifsg-meldebogen,templateId=raw,property=publicationFile.pdf/b-ifsg-meldebogen.pdf'
 		)
@@ -1025,7 +989,7 @@ class cVaccinationEAPnl(wxgVaccinationEAPnl.wxgVaccinationEAPnl, gmEditArea.cGen
 		if url.strip() == u'':
 			url = dbcfg.get2 (
 				option = u'external.urls.report_ADR',
-				workplace = gmSurgery.gmCurrentPractice().active_workplace,
+				workplace = gmPraxis.gmCurrentPraxisBranch().active_workplace,
 				bias = u'user'
 			)
 		gmNetworkTools.open_url_in_browser(url = url)
