@@ -11,7 +11,6 @@ import sys
 # 3rd party
 import wx
 
-
 # GNUmed
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
@@ -23,7 +22,7 @@ from Gnumed.pycommon import gmI18N
 from Gnumed.pycommon import gmExceptions
 from Gnumed.pycommon import gmDateTime
 
-from Gnumed.business import gmSurgery
+from Gnumed.business import gmPraxis
 from Gnumed.business import gmPerson
 
 from Gnumed.wxpython import gmEditArea
@@ -95,7 +94,7 @@ class cWaitingListEntryEditAreaPnl(wxgWaitingListEntryEditAreaPnl.wxgWaitingList
 			self.data = data
 			self.mode = 'edit'
 
-		praxis = gmSurgery.gmCurrentPractice()
+		praxis = gmPraxis.gmCurrentPraxisBranch()
 		pats = praxis.waiting_list_patients
 		zones = {}
 		zones.update([ [p['waiting_zone'], None] for p in pats if p['waiting_zone'] is not None ])
@@ -152,7 +151,7 @@ class cWaitingListEntryEditAreaPnl(wxgWaitingListEntryEditAreaPnl.wxgWaitingList
 		return True
 	#----------------------------------------------------------------
 	def _save_as_update(self):
-		gmSurgery.gmCurrentPractice().update_in_waiting_list (
+		gmPraxis.gmCurrentPraxisBranch().update_in_waiting_list (
 			pk = self.data['pk_waiting_list'],
 			urgency = self._SPCTRL_urgency.GetValue(),
 			comment = self._TCTRL_comment.GetValue().strip(),
@@ -182,7 +181,7 @@ class cWaitingListPnl(wxgWaitingListPnl.wxgWaitingListPnl, gmRegetMixin.cRegetOn
 		self._LCTRL_patients.set_columns ([
 			_('Zone'),
 			_('Urgency'),
-			#' ! ',
+			_('Registered'),
 			_('Waiting time'),
 			_('Patient'),
 			_('Born'),
@@ -259,13 +258,14 @@ class cWaitingListPnl(wxgWaitingListPnl.wxgWaitingListPnl, gmRegetMixin.cRegetOn
 		return tt
 	#--------------------------------------------------------
 	def __register_events(self):
-		gmDispatcher.connect(signal = u'waiting_list_generic_mod_db', receiver = self._on_waiting_list_modified)
+		gmDispatcher.connect(signal = u'clin.waiting_list_mod_db', receiver = self._on_waiting_list_modified)
 		gmDispatcher.connect(signal = u'post_patient_selection', receiver = self._on_post_patient_selection)
 	#--------------------------------------------------------
 	def __refresh_waiting_list(self):
 		self.__id_most_recently_activated_patient = None
+		col, ascending = self._LCTRL_patients.GetSortState()	# preserve sorting order
 
-		praxis = gmSurgery.gmCurrentPractice()
+		praxis = gmPraxis.gmCurrentPraxisBranch()
 		pats = praxis.waiting_list_patients
 
 		# set matcher to all zones currently in use
@@ -291,6 +291,7 @@ class cWaitingListPnl(wxgWaitingListPnl.wxgWaitingListPnl, gmRegetMixin.cRegetOn
 			[ [
 				gmTools.coalesce(p['waiting_zone'], u''),
 				p['urgency'],
+				gmDateTime.pydt_strftime(p['registered'], format='%Y %b %d %H:%M'),
 				gmDateTime.format_interval_medically(p['waiting_time']),
 				u'%s, %s (%s)' % (p['lastnames'], p['firstnames'], p['l10n_gender']),
 				gmTools.coalesce (
@@ -314,6 +315,7 @@ class cWaitingListPnl(wxgWaitingListPnl.wxgWaitingListPnl, gmRegetMixin.cRegetOn
 				new_selections.append(new_pks.index(old_pk))
 		self._LCTRL_patients.selections = new_selections
 		self._LCTRL_patients.Refresh()
+		self._LCTRL_patients.SortListItems(col, ascending) # re-sort
 
 		self._LBL_no_of_patients.SetLabel(_('(%s patients)') % len(pats))
 
@@ -407,7 +409,7 @@ class cWaitingListPnl(wxgWaitingListPnl.wxgWaitingListPnl, gmRegetMixin.cRegetOn
 			return
 		self.__id_most_recently_activated_patient = item['pk_identity']
 		self.__comment_most_recently_activated_patient = gmTools.coalesce(item['comment'], u'').strip()
-		gmSurgery.gmCurrentPractice().remove_from_waiting_list(pk = item['pk_waiting_list'])
+		gmPraxis.gmCurrentPraxisBranch().remove_from_waiting_list(pk = item['pk_waiting_list'])
 		curr_pat = gmPerson.gmCurrentPatient()
 		if curr_pat.connected:
 			if curr_pat.ID == item['pk_identity']:
@@ -466,21 +468,21 @@ class cWaitingListPnl(wxgWaitingListPnl.wxgWaitingListPnl, gmRegetMixin.cRegetOn
 		)
 		if not do_delete:
 			return
-		gmSurgery.gmCurrentPractice().remove_from_waiting_list(pk = item['pk_waiting_list'])
+		gmPraxis.gmCurrentPraxisBranch().remove_from_waiting_list(pk = item['pk_waiting_list'])
 	#--------------------------------------------------------
 	def _on_up_button_pressed(self, evt):
 		self.__id_most_recently_activated_patient = None
 		item = self._LCTRL_patients.get_selected_item_data(only_one=True)
 		if item is None:
 			return
-		gmSurgery.gmCurrentPractice().raise_in_waiting_list(current_position = item['list_position'])
+		gmPraxis.gmCurrentPraxisBranch().raise_in_waiting_list(current_position = item['list_position'])
 	#--------------------------------------------------------
 	def _on_down_button_pressed(self, evt):
 		self.__id_most_recently_activated_patient = None
 		item = self._LCTRL_patients.get_selected_item_data(only_one=True)
 		if item is None:
 			return
-		gmSurgery.gmCurrentPractice().lower_in_waiting_list(current_position = item['list_position'])
+		gmPraxis.gmCurrentPraxisBranch().lower_in_waiting_list(current_position = item['list_position'])
 	#--------------------------------------------------------
 	def _on_active_patient_only_checked(self, evt):
 		self.__refresh_waiting_list()
